==> mautrix-0.5.4.tar.gz: mautrix-0.5.4/mautrix/client/api/types/event/__init__.py <==
# Copyright (c) 2020 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .base import EventType
from .redaction import RedactionEventContent, RedactionEvent
from .message import (MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent,
                      LocationMessageEventContent, LocationInfo, RelationType, MessageType, Format,
                      MediaInfo, FileInfo, AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo,
                      TextMessageEventContent, BaseMessageEventContent, RelatesTo, BaseFileInfo,
                      EncryptedFile, JSONWebKey)
from .reaction import ReactionEventContent, ReactionEvent
from .state import (PowerLevelStateEventContent, Membership, MemberStateEventContent, StateEvent,
                    AliasesStateEventContent, CanonicalAliasStateEventContent, StrippedStateEvent,
                    RoomNameStateEventContent, RoomTopicStateEventContent,
                    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
                    RoomTombstoneEventContent, StateEventContent)
from .account_data import (AccountDataEvent, AccountDataEventContent, RoomTagInfo,
                           RoomTagAccountDataEventContent)
from .ephemeral import (TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
                        PresenceEventContent, SingleReceiptEventContent, ReceiptEventContent,
                        ReceiptEvent, ReceiptType)
from .encrypted import EncryptedEvent, EncryptedEventContent, EncryptionAlgorithm
from .generic import Event, EventContent, GenericEvent

==> mautrix-0.6.0b6.tar.gz: mautrix-0.6.0b6/mautrix/client/api/types/event/__init__.py <==
# Copyright (c) 2020 Tulir Asokan
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
from .type import EventType
from .base import GenericEvent
from .redaction import RedactionEventContent, RedactionEvent
from .message import (MessageEvent, MessageEventContent, MessageUnsigned, MediaMessageEventContent,
                      LocationMessageEventContent, LocationInfo, RelationType, MessageType, Format,
                      MediaInfo, FileInfo, AudioInfo, VideoInfo, ImageInfo, ThumbnailInfo,
                      TextMessageEventContent, BaseMessageEventContent, RelatesTo, BaseFileInfo,
                      EncryptedFile, JSONWebKey)
from .reaction import ReactionEventContent, ReactionEvent
from .state import (PowerLevelStateEventContent, Membership, MemberStateEventContent, StateEvent,
                    AliasesStateEventContent, CanonicalAliasStateEventContent, StrippedStateEvent,
                    RoomNameStateEventContent, RoomTopicStateEventContent,
                    RoomPinnedEventsStateEventContent, StateUnsigned, RoomAvatarStateEventContent,
                    RoomTombstoneEventContent, StateEventContent)
from .account_data import (AccountDataEvent, AccountDataEventContent, RoomTagInfo,
                           RoomTagAccountDataEventContent)
from .ephemeral import (TypingEventContent, TypingEvent, PresenceEvent, PresenceState,
                        PresenceEventContent, SingleReceiptEventContent, ReceiptEventContent,
                        ReceiptEvent, ReceiptType, EphemeralEvent)
from .encrypted import (EncryptedEvent, EncryptedEventContent, EncryptionAlgorithm,
                        EncryptedOlmEventContent, EncryptedMegolmEventContent,
                        EncryptionKeyAlgorithm, OlmMsgType, OlmCiphertext)
from .to_device import (ToDeviceEvent, ToDeviceEventContent,  RoomKeyWithheldCode,
                        RoomKeyWithheldEventContent, RoomKeyEventContent)
from .generic import Event, EventContent
